==> chromium-browser_70.0.3538.110.orig.tar.xz: chromium-70.0.3538.110/tools/perf/core/undocumented_benchmarks.py <==
# Copyright 2018 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

# This file contains the list of undocumented bechmarks. For new benchmarks,
# please make sure that they are well-documented. The list of undocumented
# benchmarks should shrink overtime.
UNDOCUMENTED_BENCHMARKS = {
  'angle_perftests',
  'components_perftests',
  'dromaeo',
  'dummy_benchmark.histogram_benchmark_1',
  'dummy_benchmark.noisy_benchmark_1',
  'dummy_benchmark.stable_benchmark_1',
  'gpu_perftests',
  'jetstream',
  'kraken',
  'load_library_perf_tests',
  'media.desktop',
  'media.mobile',
  'media_perftests',
  'memory.desktop',
  'memory.long_running_idle_gmail_background_tbmv2',
  'memory.long_running_idle_gmail_tbmv2',
  'memory.top_10_mobile',
  'net_perftests',
  'octane',
  'oortonline_tbmv2',
  'passthrough_command_buffer_perftests',
  'performance_browser_tests',
  'rasterize_and_record_micro.partial_invalidation',
  'rasterize_and_record_micro.top_25',
  'resource_sizes',
  'sizes (linux)',
  'sizes (mac)',
  'sizes (win)',
  'smoothness.gpu_rasterization.tough_pinch_zoom_cases',
  'smoothness.tough_pinch_zoom_cases',
  'speedometer',
  'speedometer-future',
  'speedometer2',
  'speedometer2-future',
  'start_with_url.cold.startup_pages',
  'start_with_url.warm.startup_pages',
  'supersize_archive',
  'system_health.webview_startup',
  'tab_switching.typical_25',
  'tracing.tracing_with_background_memory_infra',
  'tracing_perftests',
  'v8.browsing_desktop',
  'v8.browsing_desktop-future',
  'v8.browsing_mobile',
  'v8.browsing_mobile-future',
  'v8.runtime_stats.top_25',
  'validating_command_buffer_perftests',
  'views_perftests',
  'wasm',
}

==> chromium-browser_71.0.3578.80.orig.tar.xz: chromium-71.0.3578.80/tools/perf/core/undocumented_benchmarks.py <==
# Copyright 2018 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

# This file contains the list of undocumented bechmarks. For new benchmarks,
# please make sure that they are well-documented. The list of undocumented
# benchmarks should shrink overtime.
UNDOCUMENTED_BENCHMARKS = {
  'angle_perftests',
  'components_perftests',
  'dromaeo',
  'dummy_benchmark.histogram_benchmark_1',
  'dummy_benchmark.noisy_benchmark_1',
  'dummy_benchmark.stable_benchmark_1',
  'gpu_perftests',
  'jetstream',
  'kraken',
  'load_library_perf_tests',
  'media.desktop',
  'media.mobile',
  'media_perftests',
  'memory.desktop',
  'memory.long_running_idle_gmail_background_tbmv2',
  'memory.long_running_idle_gmail_tbmv2',
  'memory.top_10_mobile',
  'net_perftests',
  'octane',
  'oortonline_tbmv2',
  'passthrough_command_buffer_perftests',
  'performance_browser_tests',
  'rasterize_and_record_micro.partial_invalidation',
  'rasterize_and_record_micro.top_25',
  'resource_sizes',
  'sizes (mac)',
  'sizes (win)',
  'smoothness.gpu_rasterization.tough_pinch_zoom_cases',
  'smoothness.tough_pinch_zoom_cases',
  'speedometer',
  'speedometer-future',
  'speedometer2',
  'speedometer2-future',
  'startup.mobile',
  'supersize_archive',
  'system_health.webview_startup',
  'tab_switching.typical_25',
  'tracing.tracing_with_background_memory_infra',
  'tracing_perftests',
  'v8.browsing_desktop',
  'v8.browsing_desktop-future',
  'v8.browsing_mobile',
  'v8.browsing_mobile-future',
  'v8.runtime_stats.top_25',
  'validating_command_buffer_perftests',
  'views_perftests',
  'wasm',
}
